@@ -101,7 +101,7 @@ namespace signals {
   } // namespace ui
 
   namespace ui_tray {
-    struct mapped_clients : public detail::value_signal<mapped_clients, unsigned int> {
+    struct tray_pos_change : public detail::value_signal<tray_pos_change, int> {
       using base_type::base_type;
     };
   } // namespace ui_tray
