@@ -3,6 +3,7 @@
 #include <atomic>
 
 #include "modules/meta/timer_module.hpp"
+#include "modules/meta/types.hpp"
 #include "settings.hpp"
 #include "utils/http.hpp"
 
@@ -14,13 +15,13 @@ namespace modules {
    */
   class github_module : public timer_module<github_module> {
    public:
-    explicit github_module(const bar_settings&, string);
+    explicit github_module(const bar_settings&, string, const config&);
 
     bool update();
     bool build(builder* builder, const string& tag) const;
     string get_format() const;
 
-    static constexpr auto TYPE = "internal/github";
+    static constexpr auto TYPE = GITHUB_TYPE;
 
    private:
     void update_label(int);
@@ -35,7 +36,7 @@ namespace modules {
     string m_api_url;
     string m_user;
     string m_accesstoken{};
-    unique_ptr<http_downloader> m_http{};
+    http_downloader m_http{};
     bool m_empty_notifications{false};
     std::atomic<bool> m_offline{false};
   };
