@@ -22,7 +22,7 @@ namespace modules {
       try {
         // Warm up module output before entering the loop
         std::unique_lock<std::mutex> guard(this->m_updatelock);
-        CAST_MOD(Impl)->on_event(nullptr);
+        CAST_MOD(Impl)->on_event({});
         CAST_MOD(Impl)->broadcast();
         guard.unlock();
 
@@ -47,15 +47,14 @@ namespace modules {
     }
 
     void poll_events() {
-      vector<unique_ptr<inotify_watch>> watches;
+      vector<inotify_watch> watches;
 
       try {
         for (auto&& w : m_watchlist) {
-          watches.emplace_back(inotify_util::make_watch(w.first));
-          watches.back()->attach(w.second);
+          watches.emplace_back(w.first);
+          watches.back().attach(w.second);
         }
       } catch (const system_error& e) {
-        watches.clear();
         this->m_log.err("%s: Error while creating inotify watch (what: %s)", this->name(), e.what());
         CAST_MOD(Impl)->sleep(0.1s);
         return;
@@ -63,24 +62,20 @@ namespace modules {
 
       while (this->running()) {
         for (auto&& w : watches) {
-          this->m_log.trace_x("%s: Poll inotify watch %s", this->name(), w->path());
+          this->m_log.trace_x("%s: Poll inotify watch %s", this->name(), w.path());
 
-          if (w->poll(1000 / watches.size())) {
-            auto event = w->get_event();
-
-            for (auto&& w : watches) {
-              w->remove(true);
-            }
-
-            if (CAST_MOD(Impl)->on_event(event.get())) {
+          if (w.poll(1000 / watches.size())) {
+            auto event = w.get_event();
+            if (CAST_MOD(Impl)->on_event(event)) {
               CAST_MOD(Impl)->broadcast();
             }
             CAST_MOD(Impl)->idle();
             return;
           }
 
-          if (!this->running())
+          if (!this->running()) {
             break;
+          }
         }
         CAST_MOD(Impl)->idle();
       }
@@ -89,6 +84,6 @@ namespace modules {
    private:
     map<string, int> m_watchlist;
   };
-}  // namespace modules
+} // namespace modules
 
 POLYBAR_NS_END
