@@ -1,14 +1,14 @@
 #include "modules/battery.hpp"
+
 #include "drawtypes/animation.hpp"
 #include "drawtypes/label.hpp"
 #include "drawtypes/progressbar.hpp"
 #include "drawtypes/ramp.hpp"
+#include "modules/meta/base.inl"
 #include "utils/file.hpp"
 #include "utils/math.hpp"
 #include "utils/string.hpp"
 
-#include "modules/meta/base.inl"
-
 POLYBAR_NS
 
 namespace modules {
@@ -23,8 +23,8 @@ namespace modules {
   /**
    * Bootstrap module by setting up required components
    */
-  battery_module::battery_module(const bar_settings& bar, string name_)
-      : inotify_module<battery_module>(bar, move(name_)) {
+  battery_module::battery_module(const bar_settings& bar, string name_, const config& config)
+      : inotify_module<battery_module>(bar, move(name_), config) {
     // Load configuration values
     m_fullat = std::min(m_conf.get(name(), "full-at", m_fullat), 100);
     m_lowat = std::max(m_conf.get(name(), "low-at", m_lowat), 0);
@@ -36,8 +36,8 @@ namespace modules {
 
     // Make state reader
     if (file_util::exists((m_fstate = path_battery + "status"))) {
-          m_state_reader =
-              make_unique<state_reader>([=] { return file_util::contents(m_fstate).compare(0, 8, "Charging") == 0; });
+      m_state_reader =
+          make_unique<state_reader>([=] { return file_util::contents(m_fstate).compare(0, 8, "Charging") == 0; });
     } else if (file_util::exists((m_fstate = path_adapter + "online"))) {
       m_state_reader = make_unique<state_reader>([=] { return file_util::contents(m_fstate).compare(0, 1, "1") == 0; });
     } else {
@@ -92,9 +92,9 @@ namespace modules {
         unsigned long current{std::strtoul(file_util::contents(m_frate).c_str(), nullptr, 10)};
         unsigned long voltage{std::strtoul(file_util::contents(m_fvoltage).c_str(), nullptr, 10)};
 
-        consumption = ((voltage / 1000.0) * (current /  1000.0)) / 1e6;
-      // if it was power, just use as is
+        consumption = ((voltage / 1000.0) * (current / 1000.0)) / 1e6;
       } else {
+        // if it was power, just use as is
         unsigned long power{std::strtoul(file_util::contents(m_frate).c_str(), nullptr, 10)};
 
         consumption = power / 1e6;
@@ -199,7 +199,7 @@ namespace modules {
       if (chrono::duration_cast<decltype(m_interval)>(now - m_lastpoll) > m_interval) {
         m_lastpoll = now;
         m_log.info("%s: Polling values (inotify fallback)", name());
-        on_event(nullptr);
+        on_event({});
       }
     }
 
@@ -209,15 +209,15 @@ namespace modules {
   /**
    * Update values when tracked files have changed
    */
-  bool battery_module::on_event(inotify_event* event) {
+  bool battery_module::on_event(const inotify_event& event) {
     auto state = current_state();
     auto percentage = current_percentage();
 
     // Reset timer to avoid unnecessary polling
     m_lastpoll = chrono::steady_clock::now();
 
-    if (event != nullptr) {
-      m_log.trace("%s: Inotify event reported for %s", name(), event->filename);
+    if (event.is_valid) {
+      m_log.trace("%s: Inotify event reported for %s", name(), event.filename);
 
       if (state == m_state && percentage == m_percentage && m_unchanged--) {
         return false;
@@ -257,14 +257,17 @@ namespace modules {
    */
   string battery_module::get_format() const {
     switch (m_state) {
-      case battery_module::state::FULL: return FORMAT_FULL;
+      case battery_module::state::FULL:
+        return FORMAT_FULL;
       case battery_module::state::LOW:
         if (m_formatter->has_format(FORMAT_LOW)) {
           return FORMAT_LOW;
         }
         return FORMAT_DISCHARGING;
-      case battery_module::state::DISCHARGING: return FORMAT_DISCHARGING;
-      default: return FORMAT_CHARGING;
+      case battery_module::state::DISCHARGING:
+        return FORMAT_DISCHARGING;
+      default:
+        return FORMAT_CHARGING;
     }
   }
 
@@ -326,8 +329,8 @@ namespace modules {
   }
 
   /**
-  * Get the current power consumption
-  */
+   * Get the current power consumption
+   */
   string battery_module::current_consumption() {
     return read(*m_consumption_reader);
   }
@@ -365,7 +368,7 @@ namespace modules {
 
     while (running()) {
       auto now = chrono::steady_clock::now();
-      auto framerate = 1000U;  // milliseconds
+      auto framerate = 1000U; // milliseconds
       if (m_state == battery_module::state::CHARGING && m_animation_charging) {
         m_animation_charging->increment();
         broadcast();
@@ -387,6 +390,6 @@ namespace modules {
 
     m_log.trace("%s: End of subthread", name());
   }
-}  // namespace modules
+} // namespace modules
 
 POLYBAR_NS_END
