@@ -1,10 +1,12 @@
+#include "utils/http.hpp"
+
 #include <curl/curl.h>
 #include <curl/easy.h>
+
 #include <sstream>
 
 #include "errors.hpp"
 #include "settings.hpp"
-#include "utils/http.hpp"
 
 POLYBAR_NS
 
@@ -14,7 +16,7 @@ http_downloader::http_downloader(int connection_timeout) {
   curl_easy_setopt(m_curl, CURLOPT_CONNECTTIMEOUT, connection_timeout);
   curl_easy_setopt(m_curl, CURLOPT_FOLLOWLOCATION, true);
   curl_easy_setopt(m_curl, CURLOPT_NOSIGNAL, true);
-  curl_easy_setopt(m_curl, CURLOPT_USERAGENT, "polybar/" GIT_TAG);
+  curl_easy_setopt(m_curl, CURLOPT_USERAGENT, ("polybar/" + string{APP_VERSION}).c_str());
   curl_easy_setopt(m_curl, CURLOPT_WRITEFUNCTION, http_downloader::write);
   curl_easy_setopt(m_curl, CURLOPT_FORBID_REUSE, true);
 }
@@ -23,10 +25,16 @@ http_downloader::~http_downloader() {
   curl_easy_cleanup(m_curl);
 }
 
-string http_downloader::get(const string& url) {
+string http_downloader::get(const string& url, const string& user, const string& password) {
   std::stringstream out{};
   curl_easy_setopt(m_curl, CURLOPT_URL, url.c_str());
   curl_easy_setopt(m_curl, CURLOPT_WRITEDATA, &out);
+  if (!user.empty()) {
+    curl_easy_setopt(m_curl, CURLOPT_USERNAME, user.c_str());
+  }
+  if (!password.empty()) {
+    curl_easy_setopt(m_curl, CURLOPT_PASSWORD, password.c_str());
+  }
 
   auto res = curl_easy_perform(m_curl);
   if (res != CURLE_OK) {
