@@ -502,7 +502,8 @@ void manager::remove_client(const client& c) {
 void manager::remove_client(xcb_window_t win) {
   auto old_size = m_clients.size();
   m_clients.erase(
-      std::remove_if(m_clients.begin(), m_clients.end(), [win](const auto& client) { return client->match(win); }));
+      std::remove_if(m_clients.begin(), m_clients.end(), [win](const auto& client) { return client->match(win); }),
+      m_clients.end());
 
   if (old_size != m_clients.size()) {
     reconfigure();
@@ -518,7 +519,8 @@ void manager::remove_client(xcb_window_t win) {
  */
 void manager::clean_clients() {
   m_clients.erase(
-      std::remove_if(m_clients.begin(), m_clients.end(), [](const auto& client) { return client.get() == nullptr; }));
+      std::remove_if(m_clients.begin(), m_clients.end(), [](const auto& client) { return client.get() == nullptr; }),
+      m_clients.end());
 }
 
 bool manager::change_visibility(bool visible) {
