@@ -1,16 +1,17 @@
-#include "common/test.hpp"
 #include "utils/scope.hpp"
 
+#include "common/test.hpp"
+
 using namespace polybar;
 
 TEST(Scope, onExit) {
   auto flag = false;
   {
     EXPECT_FALSE(flag);
-    auto handler = scope_util::make_exit_handler<>([&] { flag = true; });
+    scope_util::on_exit handler([&] { flag = true; });
     EXPECT_FALSE(flag);
     {
-      auto handler = scope_util::make_exit_handler<>([&] { flag = true; });
+      scope_util::on_exit handler([&] { flag = true; });
     }
     EXPECT_TRUE(flag);
     flag = false;
